#
# spec file for package terraform-provider-vsphere
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Make sure that the binary is not getting stripped.
%if 0%{?suse_version}
%{go_nostrip}
%endif

Name:           terraform-provider-vsphere
Version:        1.18.3
Release:        bp153.2.1
Summary:        Terraform vSphere provider
License:        MPL-2.0
Group:          System/Management
URL:            https://github.com/terraform-providers/terraform-provider-vsphere
Source:         %{name}-%{version}.tar.xz
%if 0%{?suse_version}
BuildRequires:  golang-packaging
BuildRequires:  xz
BuildRequires:  golang(API) >= 1.13
%endif
Requires:       mkisofs
Requires:       terraform >= 0.12.0
BuildRequires:  git
BuildRequires:  xz
%if 0%{?suse_version}
%{go_provides}
%endif

%description
This is a terraform provider that lets you provision servers on a VMWare vSphere server.

%prep
%setup -q

%build
%{goprep} github.com/terraform-providers/terraform-provider-vsphere
%{gobuild} -mod=vendor ""
ln -s %{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}_v%{version}

%install
%{goinstall}

%check
export GOFLAGS=-mod=vendor
%{gotest} github.com/terraform-providers/terraform-provider-vsphere/...

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/%{name}
%{_bindir}/%{name}_v%{version}

%changelog
* Thu Jun 25 2020 Dirk Mueller <dmueller@suse.com>
- add symlink for terraform execution
* Mon Jun  8 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.18.3:
  * resource/custom_attribute: Fix id in error message when category is missing. (#1088)
  * resource/virtual_machine: Add vApp properties with OVF deployment. (#1082)
  * resource/host & resource/compute_cluster: Add arguments for specifying if cluster management should be handled in host or compute_cluster resource. (#1085)
  * resource/virtual_machine: Handle OVF argument validation during VM creation. (#1084)
  * resource/host: Disconnect rather than entering maintenance mode when deleting. (#1083)
  * resource/virtual_machine: Skip unexpected NIC entries. (#1067)
  * Respect session_persistence for REST sessions. (#1077)
  * resource/virtual_machine: Allow users to deploy OVF templates from both from local system and remote URL. (#1052)
  * resource/virtual_machine: Mark product_key as sensitive. (#1045)
  * resource/virtual_machine: Increase max hardware_version for vSphere v7.0. (#1056)
  * resource/virtual_machine: Fix to disk bus sorting. (#1039)
  * resource/virtual_machine: Only include hardware_version in CreateSpecs. (#1055)
  * Use built in session persistence in govmomi. (#1050)
  * resource/virtual_disk: Support VMDK files. (#987)
  * resource/virtual_machine: Fix disk controller sorting. (#1032)
  * resource/virtual_machine: Add support for hardware version tracking and upgrading. (#1020)
  * data/vsphere_network: Handle cases of network port groups with same name using distributed_virtual_switch_uuid. (#1001)
  * resource/virtual_machine: Fix working with orphaned devices. (#1005)
  * resource/virtual_machine: Ignore guest_id with content library. (#1014)
  * New Data Source: content_library (#985)
  * New Data Source: content_library_item (#985)
  * New Resource: content_library (#985)
  * New Resource: content_library_item (#985)
  * resource/virtual_machine: Add poweron_timeout option for the amount of time to give a VM to power on. (#990)
  * resource/virtual_machine: Optimize OS family query. (#959)
  * Migrate provider to Terraform plugin SDK. (#982)
* Fri Apr 24 2020 clark.hsu@suse.com
- Package terraform-provider-vsphere v1.17.3
* Sat Feb 22 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.16.1:
  bugfixes:
  * resource/virtual_machine: Set storage_policy_id based off of VM rather than template. (#970)
  * resource/virtual_machine: Do not set datastoreID in RelocateSpec when datastore_cluster is set. (#933)
  * resource/vapp_container: Fix handling of child vApp containers. (#941)
  * resource/virtual_disk: Enforce .vmdk suffix on vmdk_path. (#942)
  * resource/virtual_machine: Allow blank networkID in order to support cloning into clusters that do not include the source network. (#787)
  * resource/host: Properly handle situation where NIC teaming policy is nil. (#889)
  * Limit scope when listing network interfaces. (#840)
  * resource/compute_cluster: Set HA Admission Control Failure to off before deleting. (#891)
  * resource/virtual_machine_snapshot: Fix typo in error condition. (#906)
  * tags: Return matched tag rather than last tag in list. (#910)
  * resource/virtual_machine: Unmount ISO when switching CDROM backends. (#920)
  * resource/virtual_machine: Migrate VM when moving to different root resource pool. (#931)
  * resource/virtual_machine: Change the way we detect if a VM is in a vApp. (#825)
  * Delete tags and tag_categories when they are removed. (#801)
  * resource/virtual_machine: Ignore validation when interpolation is not available. (#784)
  * resource/virtual_machine: Only set vApp properties that are UserConfigurable. (#751)
  * resource/virtual_machine: Set network_id to empty string when cloning a virtual_machine to a cluster that is not part of source DVS. (#787)
  features:
  * New Data Source: storage_policy (#881)
  * resource/virtual_machine: Do not throw error when disk path is not known yet. (#944)
  * resource/host Add details to error messages. (#850)
  * resource/virtual_machine: Pick default datastore for extra disks. (#897)
  * resource/virtual_machine: Extend ignored_guest_ips to support CIDR. (#841)
  * New Resource: vsphere_vnic (#876)
  * Add vim_keep_alive which sets a keepalive interval for VIM session. (#792)
  * resource/virtual_machine: Mark windows_sysprep_text as sensitive. (#802)
  * New Resource: vsphere_host (#836)
  * resource/virtual_machine: Allow cloning of powered on virtual machines. (#785)
  * Add keep alive timer for VIM sessions. (#792)
* Wed May 15 2019 jmassaguerpla@suse.com
- Review description
* Tue May 14 2019 <fbergmann@suse.com>
- Package terraform-provider-vsphere v1.11.0
